// Copyright(c) 1996 ObjectSpace, Inc.
// Portions Copyright(c) 1995, 1996 Hewlett-Packard Company.

package jgl;

/**
 * UnaryFunction is the interface that must be implemented by all unary function objects.
 * Every UnaryFunction object must define a single method called execute() that takes
 * a single object as its argument and returns an object. UnaryFunction objects are often
 * built to operate on a specific kind of object and must therefore cast the input parameter
 * in order to process it.
 * <p>
 * @see jgl.UnaryPredicate
 * @see jgl.BinaryFunction
 * @version 1.1
 * @author ObjectSpace, Inc.
 */

public interface UnaryFunction
  {
  /**
   * Return the result of executing with a single Object.
   * @param object The object to process.
   * @return The result of processing the input Object.
   */
  Object execute( Object object );
  }
